Command class abstract

Implementers

Constructors

Command({Validations? validations})

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validations → Validations?
final

Methods

execute() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiredValidate() → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited