CommandNotFound class

Inheritance

Constructors

CommandNotFound()

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectName → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validations → Validations?
finalinherited

Methods

execute() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiredValidate() → bool
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited