CreateCommand class abstract

Implementers

Constructors

CreateCommand()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() → Future<void>
getNavigatorFileContent(String screenName, String navigatorFileContent, DirectoryStructor directoryStructore, String module) → String
getRoutesFileContent(String screenName, String routesFileContent) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited