ScreenCreateCommand class

Inheritance
Mixed-in types

Constructors

ScreenCreateCommand({required Validations? validations, required bool createMultiple})

Properties

createMultiple → bool
final
hashCode → int
The hash code for this object.
no setterinherited
projectName → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validations → Validations?
finalinherited

Methods

checkDirectoryExist(String path) → Future<bool>
inherited
checkFileExist(String path) → Future<bool>
inherited
checkModularPatternScreenExist(String moduleName) → Future<void>
checkNonModularPatternScreenExist() → Future<void>
createDirectory(String path) → Future<void>
inherited
createScreens() → Future<void>
execute() → Future<void>
override
getModuleNameFromUser() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(String path) → Future<String>
inherited
requiredValidate() → bool
override
toString() → String
A string representation of this object.
inherited
writeFile({required String path, required String content, String? screenName}) → Future<void>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited