GridScreenCreateCommand class

Inheritance
Mixed-in types

Constructors

GridScreenCreateCommand(DirectoryStructor directoryStructor, String? moduleName, bool moduleCreated)

Properties

directoryStructor → DirectoryStructor
final
hashCode → int
The hash code for this object.
no setterinherited
moduleCreated → bool
final
moduleName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDirectoryExist(String path) → Future<bool>
inherited
checkFileExist(String path) → Future<bool>
inherited
createDirectory(String path) → Future<void>
inherited
execute() → Future<void>
override
getNavigatorFileContent(String screenName, String navigatorFileContent, DirectoryStructor directoryStructore, String module) → String
inherited
getRoutesFileContent(String screenName, String routesFileContent) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(String path) → Future<String>
inherited
toString() → String
A string representation of this object.
inherited
writeFile({required String path, required String content, String? screenName}) → Future<void>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited