SelectMenu class

Constructors

SelectMenu({required List<String> options, required Console console})

Properties

console → Console
final
currentOption ↔ int
getter/setter pair
firstTime ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOption ↔ int
getter/setter pair

Methods

ask() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited