ScreenCreateValidations class

Inheritance

Constructors

ScreenCreateValidations({required bool createMultiple})

Properties

createMultiple → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDirectoryExist(String path) → Future<bool>
inherited
checkFileExist(String path) → Future<bool>
inherited
isValidScreenName(String name) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited